# CHANGELOG

<!-- version list -->

## v1.1.0 (2026-03-27)

### Bug Fixes

- Ensure we can render weird chars
  ([`522503a`](https://github.com/nachollorca/lmti/commit/522503aa7d4fecea6bbbf257d3d3fee9089c1344))

### Chores

- Add more models to list
  ([`f25ecce`](https://github.com/nachollorca/lmti/commit/f25ecce8af02620601d4c8cb32c9850b7d931fc5))

### Continuous Integration

- Use public lmdk in ci/cd
  ([`f08e181`](https://github.com/nachollorca/lmti/commit/f08e181a90d9af44683d5cc3b6583479686fe844))

### Documentation

- Add a cool readme
  ([`44b5743`](https://github.com/nachollorca/lmti/commit/44b5743451c41cfb2522466d4b56f00155a0a19a))

### Features

- Add system instruction
  ([`8b42a28`](https://github.com/nachollorca/lmti/commit/8b42a28d2c0cf77e83550ae12724ac6ca7145567))

- Update models with new updates
  ([`2078869`](https://github.com/nachollorca/lmti/commit/20788694df9860c95af7b70c7221847b84d82ef8))


## v1.0.1 (2026-03-25)

### Bug Fixes

- Trigger release lol
  ([`cded674`](https://github.com/nachollorca/lmti/commit/cded674f25039253e5a68fa3d5691a79e2473f44))


## v1.0.0 (2026-03-24)

- Initial Release
